@@ -58,7 +58,7 @@ class Base:
         Convert the current object to json format, return the json format
         '''
         return {Utils.to_camel_case(key) : getattr(self, key)
-         for key in self.ATTRIBUTES if getattr(self, key, None)}
+         for key in self.ATTRIBUTES if getattr(self, key, None) != None}
 
     def save(self):
         '''
@@ -88,7 +88,7 @@ class Base:
         return new_holder
 
     @classmethod
-    def find(cls, filter_ = None, offset=0, limit=1000, output = 'DataFrame'):
+    def find(cls, filter_ = None, offset=0, limit=1000, order_by='', output = 'DataFrame'):
         '''
         Get maximum 1000 values that match the condition of the class and the filter condition
         Parameter:
@@ -96,7 +96,7 @@ class Base:
          filter: the filter condition for fitlering result. the default is {} (no filter)
         Return: result in corresponding output type, each single item is in current object type
         '''
-        filter_params = Utils.build_filter_params(filter_, offset, limit)
+        filter_params = Utils.build_filter_params(filter_, offset, limit, order_by)
         class_name_plural = Utils.to_camel_case(cls.name_of_class, joining='-')
         from_server = cls.db_service.get(f'/{cls.name_of_class}', query_params=filter_params)
         try:
@@ -115,7 +115,7 @@ class Base:
          filter: the filter condition for fitlering result. the default is {} (no filter)
         Return: result in corresponding output type, each single item is in current object type
         '''
-        limit = 1000
+        limit = 5000
         rows, total_number = cls.find(filter_, limit=limit, output=output)
         if total_number <= limit:
             return rows, total_number
