@@ -13,7 +13,7 @@ class Lead(Base):
     name_of_class = "leads"
 
     def __repr__(self):
-        return super().__repr__(['name','_id'])
+        return super().__repr__(['_id','name'])
 
     @classmethod
     def find_one_by_email(cls, email):
