@@ -14,4 +14,4 @@ class CohortMember(Base): #pylint: disable=[too-few-public-methods]
     name_of_class = "cohort-members"
 
     def __repr__(self):
-        return super().__repr__(['cohort','member','member_type'])
+        return super().__repr__(['_id','cohort_id','member_id','member_type'])
