@@ -23,6 +23,17 @@ class DBService():
     def __repr__(self):
         return '<DBService>'
 
+    def colab_google_login(self):
+        try:
+            from google.colab import auth
+            from oauth2client.client import GoogleCredentials
+        except:
+            print('Only avalable on Google Colab')
+            return
+        auth.authenticate_user()
+        google_access_token = GoogleCredentials.get_application_default().get_access_token().access_token
+        self.auth(google_access_token=google_access_token)
+
     def auth(self, google_access_token='', user=None):
         '''
         auth: Authenticate access to google data base (including the action of examinee entering
@@ -54,6 +65,11 @@ class DBService():
             return True
         return False
 
+    def get_current_user_id(self):
+        if not self.is_user():
+            return False
+        return self.__current_user._id
+
     def get(self, path, query_params=None):
         '''
         get: Get data from data base
